@@ -23,8 +23,11 @@ extensions = [
     'cliff.sphinxext',
     'sphinx.ext.autodoc',
     'openstackdocstheme',
+    'sphinxcontrib.rsvgconverter',
 ]
 
+autoprogram_cliff_application = 'cloudkitty'
+
 autoprogram_cliff_ignored = [
     "--format", "--column", "--max-width", "--fit-width", "--print-empty",
     "--format-config-file", "--noindent", "--quote", "--sort-column",
@@ -57,7 +60,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -74,14 +77,30 @@ html_last_updated_fmt = '%Y-%m-%d %H:%M'
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
+
+# -- Options for LaTeX output ---------------------------------------------
+
+# Disable usage of xindy https://bugzilla.redhat.com/show_bug.cgi?id=1643664
+latex_use_xindy = False
+
+latex_domain_indices = False
+
+latex_elements = {
+    'makeindex': '',
+    'printindex': '',
+    'preamble': r'\setcounter{tocdepth}{3}',
+}
+
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
+# NOTE: Specify toctree_only=True for a better document structure of
+# the generated PDF file.
 latex_documents = [
     ('index',
-     '%s.tex' % project,
+     'doc-%s.tex' % project,
      u'%s Documentation' % project,
-     u'OpenStack Foundation', 'manual'),
+     u'OpenStack Foundation', 'howto', True),
 ]
 
 # Example configuration for intersphinx: refer to the Python standard library.
